import React from "react";
import { DatePickerButtons } from "../date-picker-buttons";
import { PureComponent } from "react";
import { bool, func, string } from "prop-types";
import { isNil } from "lodash";
import { momentObj as momentType } from "react-moment-proptypes";
import { withHandlerProxy } from "@orbit-ui/react-components-shared";
export class SingleDatePickerButtons extends PureComponent {
  constructor(...args) {
    super(...args);
    this.handleClear = withHandlerProxy(this, "onClear");
    this.handleApply = withHandlerProxy(this, "onApply");
  }

  canClear() {
    const {
      date
    } = this.props;
    return !isNil(date);
  }

  render() {
    const {
      allowClear,
      clearText,
      applyText,
      className
    } = this.props;
    return React.createElement(DatePickerButtons, {
      canClear: this.canClear(),
      canApply: true,
      onClear: this.handleClear,
      onApply: this.handleApply,
      allowClear: allowClear,
      clearText: clearText,
      applyText: applyText,
      className: className
    });
  }

}
SingleDatePickerButtons.displayName = "SingleDatePickerButtons";
SingleDatePickerButtons.propTypes = {
  /**
   * A controlled date value.
   */
  date: momentType,

  /**
   * Called on clear button click.
   * @param {SyntheticEvent} event - React's original SyntheticEvent.
   * @param {Object} props - All the props.
   * @returns {void}
   */
  // eslint-disable-next-line react/no-unused-prop-types
  onClear: func,

  /**
   * Called on apply button click.
   * @param {SyntheticEvent} event - React's original SyntheticEvent.
   * @param {Object} props - All the props.
   * @returns {void}
   */
  // eslint-disable-next-line react/no-unused-prop-types
  onApply: func,

  /**
   * Whether or not the calendar selected date can be cleared.
   */
  allowClear: bool,

  /**
   * The clear button text.
   */
  clearText: string,

  /**
   * The apply button text.
   */
  applyText: string,

  /**
   * Additional classes.
   */
  className: string
};