import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import React from "react";
import { Label as SemanticLabel } from "semantic-ui-react";
import { bool, string } from "prop-types";
import { mergeClasses, throwWhenUnsupportedPropIsProvided } from "@orbit-ui/react-components-shared";
const UNSUPPORTED_PROPS = ["attached", "corner", "floating", "horizontal", "icon", "image", "onClick", "onRemove", "pointing", "prompt", "removeIcon", "ribbon"];
const propTypes = {
  /**
   * A label can be colorless. Use this variant if you need to customize the label.
   */
  naked: bool,

  /**
   * @ignore
   */
  className: string
};
const defaultProps = {
  naked: false
};
export function Label(_ref) {
  let {
    naked,
    className,
    children
  } = _ref,
      props = _objectWithoutProperties(_ref, ["naked", "className", "children"]);

  throwWhenUnsupportedPropIsProvided(props, UNSUPPORTED_PROPS);
  const classes = mergeClasses(naked && "naked", className);
  return React.createElement(SemanticLabel, Object.assign({
    className: classes
  }, props), children);
}
Label.displayName = "Label";
Label.Detail = SemanticLabel.Detail;
Label.Group = SemanticLabel.Group;
Label.propTypes = propTypes;
Label.defaultProps = defaultProps;