import { isNullOrEmpty } from "./types";
export class ExtendableError extends Error {
  constructor(message) {
    super();
    this.message = "";
    this.name = "";
    this.stack = null;
    this.message = message;
    this.name = this.constructor.name;
    this.stack = new Error(message).stack;
  }

}
export class ArgumentError extends ExtendableError {
  /**
   * @param {string} errorMessage
   */
  constructor(errorMessage) {
    const message = isNullOrEmpty(errorMessage) ? "ArgumentError" : "ArgumentError: \"".concat(errorMessage, "\"");
    super(message);
  }

}
export class ArgumentNullError extends ExtendableError {
  /**
   * @param {string} parameterName
   * @param {string} errorMessage
   */
  constructor(parameterName, errorMessage) {
    let message = "";

    if (isNullOrEmpty(parameterName) && isNullOrEmpty(errorMessage)) {
      message = "ArgumentNullError";
    } else if (isNullOrEmpty(errorMessage)) {
      message = "ArgumentNullError: \"".concat(parameterName, "\" cannot be null");
    } else {
      message = "ArgumentNullError: \"".concat(errorMessage, "\"");
    }

    super(message);
    this.parameterName = parameterName;
  }

}
export class InvalidOperationError extends ExtendableError {
  /**
   * @param {string} errorMessage
   */
  constructor(errorMessage) {
    const message = isNullOrEmpty(errorMessage) ? "InvalidOperationError" : "InvalidOperationError: \"".concat(errorMessage, "\"");
    super(message);
  }

}